==> qtjambi-uic-6.3.4-sources.jar: io/qt/uic/ui4/DomBrush.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomBrush</p>
 */
public class DomBrush extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum DomBrush::Kind</p>
     */
    public enum Kind implements io.qt.QtEnumerator {
        Unknown(0),
        Color(1),
        Texture(2),
        Gradient(3);

        private Kind(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static Kind resolve(int value) {
            switch (value) {
            case 0: return Unknown;
            case 1: return Color;
            case 2: return Texture;
            case 3: return Gradient;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public DomBrush(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomBrush instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeBrushStyle(){
        return attributeBrushStyle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeBrushStyle_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeBrushStyle(){
        clearAttributeBrushStyle_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeBrushStyle_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColor elementColor(){
        return elementColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColor elementColor_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomGradient elementGradient(){
        return elementGradient_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomGradient elementGradient_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomProperty elementTexture(){
        return elementTexture_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomProperty elementTexture_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeBrushStyle(){
        return hasAttributeBrushStyle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeBrushStyle_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomBrush.Kind kind(){
        return io.qt.uic.ui4.DomBrush.Kind.resolve(kind_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int kind_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeBrushStyle(java.lang.String a){
        setAttributeBrushStyle_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeBrushStyle_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementColor(io.qt.uic.ui4.DomColor a){
        setElementColor_native_DomColor_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementColor_native_DomColor_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementGradient(io.qt.uic.ui4.DomGradient a){
        setElementGradient_native_DomGradient_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementGradient_native_DomGradient_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementTexture(io.qt.uic.ui4.DomProperty a){
        setElementTexture_native_DomProperty_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementTexture_native_DomProperty_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColor takeElementColor(){
        return takeElementColor_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColor takeElementColor_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomGradient takeElementGradient(){
        return takeElementGradient_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomGradient takeElementGradient_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomProperty takeElementTexture(){
        return takeElementTexture_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomProperty takeElementTexture_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomBrush(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.4.2-sources.jar: io/qt/uic/ui4/DomBrush.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomBrush</p>
 */
public class DomBrush extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum DomBrush::Kind</p>
     */
    public enum Kind implements io.qt.QtEnumerator {
        Unknown(0),
        Color(1),
        Texture(2),
        Gradient(3);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Kind(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static Kind resolve(int value) {
            switch (value) {
            case 0: return Unknown;
            case 1: return Color;
            case 2: return Texture;
            case 3: return Gradient;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public DomBrush(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomBrush instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeBrushStyle(){
        return attributeBrushStyle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeBrushStyle_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeBrushStyle(){
        clearAttributeBrushStyle_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeBrushStyle_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColor elementColor(){
        return elementColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColor elementColor_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomGradient elementGradient(){
        return elementGradient_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomGradient elementGradient_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomProperty elementTexture(){
        return elementTexture_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomProperty elementTexture_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeBrushStyle(){
        return hasAttributeBrushStyle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeBrushStyle_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomBrush.Kind kind(){
        return io.qt.uic.ui4.DomBrush.Kind.resolve(kind_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int kind_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeBrushStyle(java.lang.String a){
        setAttributeBrushStyle_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeBrushStyle_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementColor(io.qt.uic.ui4.DomColor a){
        setElementColor_native_DomColor_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementColor_native_DomColor_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementGradient(io.qt.uic.ui4.DomGradient a){
        setElementGradient_native_DomGradient_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementGradient_native_DomGradient_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementTexture(io.qt.uic.ui4.DomProperty a){
        setElementTexture_native_DomProperty_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementTexture_native_DomProperty_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColor takeElementColor(){
        return takeElementColor_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColor takeElementColor_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomGradient takeElementGradient(){
        return takeElementGradient_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomGradient takeElementGradient_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomProperty takeElementTexture(){
        return takeElementTexture_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomProperty takeElementTexture_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomBrush(QPrivateConstructor p) { super(p); } 
    
}
